@@ -269,7 +269,12 @@ class Expr(object):
             return self.table.columns[self.fieldname]
         else:
             return BaseExpr(self.fieldname, self.table.columns.getTables()[0])
-        
+    
+    def getRefBase(self):
+        res = copy(self)
+        while res != res.getRef():
+            res = res.getRef()
+        return res
 
 
 class BaseExpr(Expr):
@@ -513,7 +518,9 @@ class Columns(dict):
         return f'Columns(dict= {dict.__repr__(self)}, joincond= {self.joincond}, groupbys= {self.groupbys})'#, primary= {self.primary})'
     
     def __mod__(self, other):
-        return updateUnique(self, other, makecopy=True)
+        res = updateUnique(self, other, makecopy=True)
+        res.joincond &= other.joincond
+        return res
     
     def __matmul__(self, other):
         return (self.asQuery() @ other.asQuery()).asCols()
